# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'admin.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x61\x64min.proto\x12\x10tetherhelix_grpc\")\n\x0cLoginRequest\x12\x19\n\x11\x61\x64min_certificate\x18\x01 \x01(\t\"S\n\rLoginResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x14\n\x07\x64\x62_auth\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_db_auth2\\\n\x10\x41\x64minAuthService\x12H\n\x05Login\x12\x1e.tetherhelix_grpc.LoginRequest\x1a\x1f.tetherhelix_grpc.LoginResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_LOGINREQUEST']._serialized_start=33
  _globals['_LOGINREQUEST']._serialized_end=74
  _globals['_LOGINRESPONSE']._serialized_start=76
  _globals['_LOGINRESPONSE']._serialized_end=159
  _globals['_ADMINAUTHSERVICE']._serialized_start=161
  _globals['_ADMINAUTHSERVICE']._serialized_end=253
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tetherbot.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'tetherbot.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0ftetherbot.proto\x12\x10tetherhelix_grpc\"\x9c\x01\n\x08Position\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x16\n\x0e\x62id_order_uuid\x18\x02 \x01(\t\x12\x13\n\x0b\x65ntry_price\x18\x03 \x01(\x01\x12\x0e\n\x06volume\x18\x04 \x01(\x01\x12\x16\n\x0e\x61sk_order_uuid\x18\x05 \x01(\t\x12\x12\n\ncreated_at\x18\x06 \x01(\t\x12\x14\n\x0ctarget_price\x18\x07 \x01(\x02\"\x1d\n\nKeyRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\"3\n\x0bKeyResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\"C\n\x16\x42\x61tchPositionsResponse\x12)\n\x05\x62\x61tch\x18\x01 \x03(\x0b\x32\x1a.tetherhelix_grpc.Position\"j\n\x11PositionsResponse\x12\x14\n\x0cposition_idx\x18\x01 \x01(\x05\x12,\n\x08position\x18\x02 \x01(\x0b\x32\x1a.tetherhelix_grpc.Position\x12\x11\n\ttimestamp\x18\x03 \x01(\t\"<\n\x12MarketDataResponse\x12\r\n\x05price\x18\x01 \x01(\x01\x12\x17\n\x0ftimestamp_epoch\x18\x02 \x01(\x03\x32\xb7\x03\n\x10TetherBotService\x12]\n\x13GetCurrentPositions\x12\x1c.tetherhelix_grpc.KeyRequest\x1a(.tetherhelix_grpc.BatchPositionsResponse\x12^\n\x17StreamRealTimePositions\x12\x1c.tetherhelix_grpc.KeyRequest\x1a#.tetherhelix_grpc.PositionsResponse0\x01\x12Y\n\x11StreamMarketValue\x12\x1c.tetherhelix_grpc.KeyRequest\x1a$.tetherhelix_grpc.MarketDataResponse0\x01\x12\x44\n\x05Start\x12\x1c.tetherhelix_grpc.KeyRequest\x1a\x1d.tetherhelix_grpc.KeyResponse\x12\x43\n\x04Stop\x12\x1c.tetherhelix_grpc.KeyRequest\x1a\x1d.tetherhelix_grpc.KeyResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tetherbot_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_POSITION']._serialized_start=38
  _globals['_POSITION']._serialized_end=194
  _globals['_KEYREQUEST']._serialized_start=196
  _globals['_KEYREQUEST']._serialized_end=225
  _globals['_KEYRESPONSE']._serialized_start=227
  _globals['_KEYRESPONSE']._serialized_end=278
  _globals['_BATCHPOSITIONSRESPONSE']._serialized_start=280
  _globals['_BATCHPOSITIONSRESPONSE']._serialized_end=347
  _globals['_POSITIONSRESPONSE']._serialized_start=349
  _globals['_POSITIONSRESPONSE']._serialized_end=455
  _globals['_MARKETDATARESPONSE']._serialized_start=457
  _globals['_MARKETDATARESPONSE']._serialized_end=517
  _globals['_TETHERBOTSERVICE']._serialized_start=520
  _globals['_TETHERBOTSERVICE']._serialized_end=959
# @@protoc_insertion_point(module_scope)
